# ╔════════════════════════════════════════════════════════════════╗
# ║ "Optimally temperature compensated FBG-based sensor dedicated  ║
# ║       to non-intrusive pipe internal pressure monitoring"      ║
# ║ authors: Laurent Maurin, Nicolas Roussel and Guillaume Laffont ║
# ║          (Recent Advances in Optical Fiber Sensors)            ║
# ║                                                                ║
# ║ https://www.frontiersin.org/articles/10.3389/fsens.2022.835140 ║
# ║ https://hal-cea.archives-ouvertes.fr/cea-03541365              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ gnuplot scripts for figures 2, rows 1 & 2                      ║
# ║ see http://www.gnuplot.info/ for more information              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ this gnuplot script can be loaded with the gnuplot command:    ║
# ║   gnuplot> load "plot_eps.gnu"                                 ║
# ║ _ open data are located in the "data" sub-directory            ║
# ║ _ encapsulated postscript figures generated by this script are ║
# ║   located in the "graphs" sub-directory                        ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ script validated on Linux and Microsoft Windows workstations   ║
# ║ with gnuplot 5.4.2                                             ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ before running, first relocate to the directory of this script ║
# ╚════════════════════════════════════════════════════════════════╝

set terminal eps enhanced color
set encoding utf8

set xtics autofreq

set format x "% g"
set format y "% g"
set format z "% g"

set grid

set bmargin 0
set tmargin 0
set lmargin 7
set rmargin 0

set hidden3d trianglepattern 3
set surface
set pm3d

set view 52,43

set palette gray
unset colorbox

set ticslevel 0
set tics font "Arial, 15"

unset key

set xrange [0:150]
set xlabel "{/Arial=18 P [bar]}" offset 3,-0.8,0
set xtics 30
set xtics mirror
set mxtics 3

set yrange [0:320]
set ylabel "{/Arial=18 T [°C]}" offset -2,-0.8,0
set ytics autofreq
set ytics mirror
set mytics 5

set ztics autofreq
set ztics nomirror

# ************************************************
# figure 02 row 1
# ************************************************

set lmargin 7
set zlabel "{/Arial=18 {P}_{int} relative error}" rotate by 90 offset -4,0,0
set mztics 2

set zrange [-0.0016:0]
unset ztics
set ztics add ('-2×{10}^{-4}' -2e-4, '-4×{10}^{-4}' -4e-4, '-6×{10}^{-4}' -6e-4, '-8×{10}^{-4}' -8e-4, '-10×{10}^{-4}' -10e-4, '-12×{10}^{-4}' -12e-4, '-14×{10}^{-4}' -14e-4, '-16×{10}^{-4}' -16e-4)

data="data/data_figure_02_row_1_a.txt"
set output "graphs/figure_02_row_1_a.eps"
set title "{/Arial=24 order 1 (linearized model)}\nø 2\" NPS Sch. 80 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

set lmargin 8
set zlabel "{/Arial=18 {P}_{int} relative error}" rotate by 90 offset -5,0,0
set mztics 2

set zrange [*:*]
unset ztics
set ztics add ('-2×{10}^{-7}' -2e-7, '-4×{10}^{-7}' -4e-7, '-6×{10}^{-7}' -6e-7, '-8×{10}^{-7}' -8e-7, '-10×{10}^{-7}' -10e-7, '-12×{10}^{-7}' -12e-7, '-14×{10}^{-7}' -14e-7, '-16×{10}^{-7}' -16e-7)

data="data/data_figure_02_row_1_b.txt"
set output "graphs/figure_02_row_1_b.eps"
set title "{/Arial=24 order 2}\nø 2\" NPS Sch. 80 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

unset ztics
set ztics add ('-2×{10}^{-10}' -2e-10, '-4×{10}^{-10}' -4e-10, '-6×{10}^{-10}' -6e-10, '-8×{10}^{-10}' -8e-10, '-10×{10}^{-10}' -10e-10, '-12×{10}^{-10}' -12e-10, '-14×{10}^{-10}' -14e-10, '-16×{10}^{-10}' -16e-10, '-18×{10}^{-10}' -18e-10)

data="data/data_figure_02_row_1_c.txt"
set output "graphs/figure_02_row_1_c.eps"
set title "{/Arial=24 order 3}\nø 2\" NPS Sch. 80 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

# ************************************************
# figure 02 row 2
# ************************************************

set lmargin 7
set zlabel "{/Arial=18 {P}_{int} relative error}" rotate by 90 offset -4,0,0
set mztics 2

unset ztics
set ztics add ('-2×{10}^{-4}' -2e-4, '-4×{10}^{-4}' -4e-4, '-6×{10}^{-4}' -6e-4, '-8×{10}^{-4}' -8e-4, '-10×{10}^{-4}' -10e-4, '-12×{10}^{-4}' -12e-4, '-14×{10}^{-4}' -14e-4, '-16×{10}^{-4}' -16e-4)

data="data/data_figure_02_row_2_a.txt"
set output "graphs/figure_02_row_2_a.eps"
set title "{/Arial=24 order 1 (linearized model)}\nø 4\" NPS Sch. 160 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

set mztics 1

unset ztics
set ztics add ('-1×{10}^{-7}' -1e-7, '-2×{10}^{-7}' -2e-7, '-3×{10}^{-7}' -3e-7, '-4×{10}^{-7}' -4e-7, '-5×{10}^{-7}' -5e-7, '-6×{10}^{-7}' -6e-7, '-7×{10}^{-7}' -7e-7, '-8×{10}^{-7}' -8e-7, '-9×{10}^{-7}' -9e-7)

data="data/data_figure_02_row_2_b.txt"
set output "graphs/figure_02_row_2_b.eps"
set title "{/Arial=24 order 2}\nø 4\" NPS Sch. 160 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

unset ztics
set ztics add ('-1×{10}^{-10}' -1e-10, '-2×{10}^{-10}' -2e-10, '-3×{10}^{-10}' -3e-10, '-4×{10}^{-10}' -4e-10, '-5×{10}^{-10}' -5e-10, '-6×{10}^{-10}' -6e-10, '-7×{10}^{-10}' -7e-10, '-8×{10}^{-10}' -8e-10)

data="data/data_figure_02_row_2_c.txt"
set output "graphs/figure_02_row_2_c.eps"
set title "{/Arial=24 order 3}\nø 4\" NPS Sch. 160 steel pipe (with hoop and longitudinal transducers)" offset -2,1,0
splot [0:150] [0:320] data w l notitle
set output

# ************************************************

set terminal pop
