# ╔════════════════════════════════════════════════════════════════╗
# ║ "Optimally temperature compensated FBG-based sensor dedicated  ║
# ║       to non-intrusive pipe internal pressure monitoring"      ║
# ║ authors: Laurent Maurin, Nicolas Roussel and Guillaume Laffont ║
# ║          (Recent Advances in Optical Fiber Sensors)            ║
# ║                                                                ║
# ║ https://www.frontiersin.org/articles/10.3389/fsens.2022.835140 ║
# ║ https://hal-cea.archives-ouvertes.fr/cea-03541365              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ gnuplot scripts for figures 12, 13 and 14 (left & right)       ║
# ║ see http://www.gnuplot.info/ for more information              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ this gnuplot script can be loaded with the gnuplot command:    ║
# ║   gnuplot> load "plot_eps.gnu"                                 ║
# ║ _ open data are located in the "data" sub-directory            ║
# ║ _ encapsulated postscript figures generated by this script are ║
# ║   located in the "graphs" sub-directory                        ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ script validated on Linux and Microsoft Windows workstations   ║
# ║ with gnuplot 5.4.2                                             ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ before running, first relocate to the directory of this script ║
# ╚════════════════════════════════════════════════════════════════╝

set terminal eps enhanced color
set encoding utf8

set size 1,1
set xtics autofreq
set format x "% g"
set grid

# ************************************************
# figure 12 left in page 29
# ************************************************

data="data/data_figure_12_C1.txt"         # FBG measurement file for sensor C1

set lmargin 8
set rmargin 1.2

set output "graphs/figure_12_left.eps"

set multiplot

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.3
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:64800/3600.0]
set xlabel "time [h]"
set mxtics 6

set yrange [-1:4.2]
set ytics 0,2,4
set ytics mirror
set ylabel "error [bar]\n\n"
set mytics 2

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key right top

set size 1,0.7
set origin 0.0,0.3

set bmargin 0
set tmargin 0.5

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:110]
set ytics autofreq
set ylabel "pressure [bar]"
set mytics 10

unset y2label
unset y2tics

plot data using (($1)/3600.0):($2) with lines axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines axes x1y1 title "{ΔP}_{{int}_{FBG}}"

# --------------------

unset multiplot
set output

# ************************************************
# figure 12 right in page 29
# ************************************************

data="data/data_figure_12_C1_C2_C3.txt"         # FBG average measurement file for sensors C1, C2 & C3
data_T="data/data_figure_12_TT204.txt"          # reference thermocouple temperature measurement file

set lmargin 8
set rmargin 1.2

set output "graphs/figure_12_right.eps"

set multiplot

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.3
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:64800/3600.0]
set xlabel "time [h]"
set mxtics 6

set yrange [-3:4.2]
set ytics -2,2,4
set ytics mirror
set ylabel "error [bar]\n\n"
set mytics 2

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key right top

set size 1,0.7
set origin 0.0,0.3

set bmargin 0
set tmargin 0.5

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:110]
set ytics autofreq
set ylabel "pressure [bar]"
set mytics 10

unset y2label
unset y2tics

plot data using (($1)/3600.0):($2) with lines axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines axes x1y1 title "{ΔP}_{{int}_{FBG}}"

# --------------------

unset multiplot
set output

# ************************************************
# figure 13 left in page 29
# ************************************************

data="data/data_figure_13_C1.txt"               # FBG measurement file for sensor C1
data_T="data/data_figure_13_TT204.txt"          # reference thermocouple temperature measurement file

set lmargin 8
set rmargin 7.5

set output "graphs/figure_13_left.eps"

set multiplot

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.3
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:144000/3600.0]
set xlabel "time [h]"
set mxtics 5

set yrange [-5:7]
set ytics -3,3,6
set ytics mirror
set ylabel "error [bar]\n\n"
set mytics 3

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key right top

set size 1,0.7
set origin 0.0,0.3

set bmargin 0
set tmargin 0.5

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:110]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"
set mytics 10

set y2range [-1:20]
set y2label "ΔT [°C]" rotate by -90
set y2tics autofreq
set my2tics 5

T0=22.9       # reference temperature [°C]

plot data using (($1)/3600.0):($2) with lines lw 2 axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines lw 2 axes x1y1 title "{ΔP}_{{int}_{FBG}}", data_T using (($1)/3600.0):(($2)-T0) with lines lw 1 axes x1y2 title "Δ{T}_{ref}", data using (($1)/3600.0):($8) with lines lw 1 axes x1y2 title "{ΔT}_{FBG}"

# --------------------

unset multiplot
set output

# ************************************************
# figure 13 right in page 29
# ************************************************

data="data/data_figure_13_C1_C2_C3.txt"         # FBG average measurement file for sensors C1, C2 & C3
data_T="data/data_figure_13_TT204.txt"          # reference thermocouple temperature measurement file

set lmargin 8
set rmargin 7.5

set output "graphs/figure_13_right.eps"

set multiplot

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.3
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:144000/3600.0]
set xlabel "time [h]"
set mxtics 5

set yrange [-8:4]
set ytics -6,3,3
set ytics mirror
set ylabel "error [bar]\n\n"
set mytics 3

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key right top

set size 1,0.7
set origin 0.0,0.3

set bmargin 0
set tmargin 0.5

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:110]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"
set mytics 10

set y2range [-1:20]
set y2label "ΔT [°C]" rotate by -90
set y2tics autofreq
set my2tics 5

T0=22.9       # reference temperature [°C]

plot data using (($1)/3600.0):($2) with lines lw 2 axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines lw 2 axes x1y1 title "{ΔP}_{{int}_{FBG}}", data_T using (($1)/3600.0):(($2)-T0) with lines lw 1 axes x1y2 title "Δ{T}_{ref}", data using (($1)/3600.0):($8) with lines lw 1 axes x1y2 title "{ΔT}_{FBG}"

# --------------------

unset multiplot
set output

# ************************************************
# figure 14 left in page 30
# ************************************************

data="data/data_figure_14_C13.txt"              # FBG measurement file for sensor C13
data_T="data/data_figure_14_TT201.txt"          # reference thermocouple temperature measurement file
data_Q="data/data_figure_14_FT201.txt"          # flow rate measurement file

set lmargin 8
set rmargin 7.5

set output "graphs/figure_14_left.eps"

set multiplot

# --------------------
# water flow sub-graph
# --------------------

set key right top

set size 1,0.25
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:108000/3600.0]
set xlabel "time [h]"
set xtics 2
unset mxtics

unset ylabel
set yrange [-1:13]
unset ytics
set format y ""
unset mytics

set y2range [-1:13]
set y2tics 5
set y2tics mirror
set y2label "Q [{m}^{3}/h]" rotate by -90
set my2tics 5

plot data_Q using (($1)/3600.0):($2) with lines axes x1y2 title "water flow"

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.15
set origin 0.0,0.25

set bmargin 0
set tmargin 0

set format x ""
set xlabel ""
set mxtics 6

set yrange [-12:6.5]
set ytics 5
set ylabel "error [bar]\n"
set format y "% g"
set mytics 5

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key center bottom

set size 1,0.58
set origin 0.0,0.4

set bmargin 0
set tmargin 0

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:115]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"
set mytics 10

set y2range [-1.8:40]
set y2label "ΔT [°C]" rotate by -90
set y2tics autofreq
set my2tics 5

T0=23.0       # reference temperature [°C]

plot data using (($1)/3600.0):($2) with lines lw 2 axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines lw 2 axes x1y1 title "{ΔP}_{{int}_{FBG}}", data_T using (($1)/3600.0):(($2)-T0) with lines lw 1 axes x1y2 title "Δ{T}_{ref}", data using (($1)/3600.0):($8) with lines lw 1 axes x1y2 title "{ΔT}_{FBG}"

# --------------------

unset multiplot
set output

# ************************************************
# figure 14 right in page 30
# ************************************************

data="data/data_figure_14_C13_C14.txt"          # FBG average measurement file for sensors C13 & C14
data_T="data/data_figure_14_TT201.txt"          # reference thermocouple temperature measurement file
data_Q="data/data_figure_14_FT201.txt"          # flow rate measurement file

set lmargin 8
set rmargin 7.5

set output "graphs/figure_14_right.eps"

set multiplot

# --------------------
# water flow sub-graph
# --------------------

set key right top

set size 1,0.25
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:108000/3600.0]
set xlabel "time [h]"
set xtics 2
unset mxtics

unset ylabel
set yrange [-1:13]
unset ytics
set format y ""
unset mytics

set y2range [-1:13]
set y2tics 5
set y2tics mirror
set y2label "Q [{m}^{3}/h]" rotate by -90
set my2tics 5

plot data_Q using (($1)/3600.0):($2) with lines axes x1y2 title "water flow"

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.15
set origin 0.0,0.25

set bmargin 0
set tmargin 0

set format x ""
set xlabel ""
set mxtics 6

set yrange [-12:6.5]
set ytics 5
set ylabel "error [bar]\n"
set format y "% g"
set mytics 5

unset y2label
unset y2tics

plot data using (($1)/3600.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key center bottom

set size 1,0.58
set origin 0.0,0.4

set bmargin 0
set tmargin 0

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:115]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"
set mytics 10

set y2range [-1.8:40]
set y2label "ΔT [°C]" rotate by -90
set y2tics autofreq
set my2tics 5

T0=23.0       # reference temperature [°C]

plot data using (($1)/3600.0):($2) with lines lw 2 axes x1y1 title "{P}_{{int}_{ref}}", data using (($1)/3600.0):($6) with lines lw 2 axes x1y1 title "{ΔP}_{{int}_{FBG}}", data_T using (($1)/3600.0):(($2)-T0) with lines lw 1 axes x1y2 title "Δ{T}_{ref}", data using (($1)/3600.0):($8) with lines lw 1 axes x1y2 title "{ΔT}_{FBG}"

# --------------------

unset multiplot
set output

# ************************************************

set terminal pop
