# ╔════════════════════════════════════════════════════════════════╗
# ║ "Optimally temperature compensated FBG-based sensor dedicated  ║
# ║       to non-intrusive pipe internal pressure monitoring"      ║
# ║ authors: Laurent Maurin, Nicolas Roussel and Guillaume Laffont ║
# ║          (Recent Advances in Optical Fiber Sensors)            ║
# ║                                                                ║
# ║ https://www.frontiersin.org/articles/10.3389/fsens.2022.835140 ║
# ║ https://hal-cea.archives-ouvertes.fr/cea-03541365              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ gnuplot scripts for figures 7 and 8 (left & right)             ║
# ║ see http://www.gnuplot.info/ for more information              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ this gnuplot script can be loaded with the gnuplot command:    ║
# ║   gnuplot> load "plot_eps.gnu"                                 ║
# ║ _ open data are located in the "data" sub-directory            ║
# ║ _ encapsulated postscript figures generated by this script are ║
# ║   located in the "graphs" sub-directory                        ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ script validated on Linux and Microsoft Windows workstations   ║
# ║ with gnuplot 5.4.2                                             ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ before running, first relocate to the directory of this script ║
# ╚════════════════════════════════════════════════════════════════╝

set terminal eps enhanced color size 12cm,7cm
set encoding utf8

set size 1,1
set xtics autofreq
set grid

# ************************************************
# figure 7 in page 25
# ************************************************

data_P="data/data_figures_7_and_8_P_nu_0_30.txt"
data_T="data/data_figures_7_and_8_T.txt"

set lmargin 7.5
set rmargin 8.9

set output "graphs/figure_07.eps"

set multiplot

# --------------------
# pressure measurement error sub-graph
# --------------------

set key right top

set size 1,0.3
set origin 0.0,0.0

set bmargin 3
set tmargin 0

set format x "% g"

set xrange [0:60]
set xlabel "time [min]"
set mxtics 5

set yrange [-2.5:5]
set ytics autofreq
set ytics -2,2,4
set ytics mirror
set ylabel "error [bar]\n\n"
set mytics 2

unset y2label
unset y2tics

plot data_P using (($1)/60.0):($7) with lines axes x1y1 title "pressure measurement error"

# --------------------
# pressure measurement sub-graph
# --------------------

set key right top

set size 1,0.7
set origin 0.0,0.3

set bmargin 0
set tmargin 0.5

set format x ""
set xlabel ""
unset mxtics

set yrange [-5:310]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"
set mytics 5

set y2range [27.4:28.2]
set y2label "T [°C]" rotate by -90
set y2tics
unset my2tics

plot data_P using (($1)/60.0):($2) with lines axes x1y1 title "{P}_{{int}_{ref}}", data_P using (($1)/60.0):($6) with lines axes x1y1 title "{ΔP}_{{int}_{FBG}}", data_T using (($1)/60.0):($2) with lines axes x1y2 title "{T}_{TC}"

# --------------------

unset multiplot
set output

# ************************************************
# figures 8 left and right in page 25
# ************************************************

data_P_nu_0_30="data/data_figures_7_and_8_P_nu_0_30.txt"
data_P_nu_0_35="data/data_figures_7_and_8_P_nu_0_35.txt"

set lmargin 8
set rmargin 8.2

# --------------------

set size 1,1
set origin 0.0,0.0

set bmargin 3
set tmargin 0.5

set key right top

set format x "% g"

set xrange [0:60]
set xlabel "time [min]"
set mxtics 5

set yrange [-5:310]
set ytics autofreq
set ytics nomirror
set ylabel "pressure [bar]"

set y2range [-1.5:1]
set y2label "ΔT [°C]" rotate by -90
set y2tics

T0=27.6749101597251    # reference thermocouple temperature measurement [°C]

# --------------------
# figure 8 left
# --------------------

set output "graphs/figure_08_left.eps"
plot data_P_nu_0_30 using (($1)/60.0):($2) with lines axes x1y1 title "{P}_{{int}_{ref}}", data_T using (($1)/60.0):(($2)-T0) with lines axes x1y2 title "{ΔT}_{TC}", data_P_nu_0_30 using (($1)/60.0):($8) with lines axes x1y2 title "{ΔT}_{FBG}"
set output

# --------------------
# figure 8 right
# --------------------

set output "graphs/figure_08_right.eps"
plot data_P_nu_0_35 using (($1)/60.0):($2) with lines axes x1y1 title "{P}_{{int}_{ref}}", data_T using (($1)/60.0):(($2)-T0) with lines axes x1y2 title "{ΔT}_{TC}", data_P_nu_0_35 using (($1)/60.0):($8) with lines axes x1y2 title "{ΔT}_{FBG}"
set output

# ************************************************

set terminal pop
